.. This file is a part of the AnyBlok / Pyramidproject
..
..    Copyright (C) 2015 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

AnyBlok / Pyramid framework
===========================

anyblok_pyramid.pyramid_config
------------------------------

.. automodule:: anyblok_pyramid.pyramid_config

.. autoclass:: Configurator
    :show-inheritance:
    :members:
    :noindex:

.. autoclass:: AnyBlokRequest
    :show-inheritance:
    :members:
    :noindex:

.. autoclass:: InstalledBlokPredicate
    :show-inheritance:
    :members:
    :noindex:

pyramid_config.settings
~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: pyramid_settings
    :noindex:

pyramid_config.includeme
~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: static_paths
    :noindex:

anyblok_pyramid.adapter module
------------------------------

.. automodule:: anyblok_pyramid.adapter

.. autofunction:: datetime_adapter
    :noindex:

.. autofunction:: date_adapter
    :noindex:

.. autofunction:: uuid_adapter
    :noindex:

.. autofunction:: bytes_adapter
    :noindex:

.. autofunction:: decimal_adapter
    :noindex:

anyblok_pyramid.scripts module
------------------------------

.. automodule:: anyblok_pyramid.scripts

.. autofunction:: wsgi
    :noindex:

.. autofunction:: gunicorn_wsgi
    :noindex:

anyblok_pyramid.security module
-------------------------------

.. automodule:: anyblok_pyramid.security

.. autofunction:: group_finder
    :noindex:

.. autofunction:: check_user
    :noindex:

.. autofunction:: AnyBlokResourceFactory
    :noindex:

.. autoclass:: RootFactory
    :noindex:
    :members:
